==> jc-1.4.0.tar.gz: java/awt/Container__24GfxVisitor.h <==
// abstract class java.awt.Container$GfxVisitor

// class file dependencies
// @dep_class a0c7f2977640055f java_awt_Container__24GfxVisitor
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Container__24GfxVisitor_H_
#define _JC_java_awt_Container__24GfxVisitor_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Container__24GfxVisitor$sub_refs	_jc_java_awt_Container__24GfxVisitor$sub_refs;
typedef struct _jc_java_awt_Container__24GfxVisitor$sub_nonrefs	_jc_java_awt_Container__24GfxVisitor$sub_nonrefs;
typedef struct _jc_java_awt_Container__24GfxVisitor$refs	_jc_java_awt_Container__24GfxVisitor$refs;
typedef struct _jc_java_awt_Container__24GfxVisitor$nonrefs	_jc_java_awt_Container__24GfxVisitor$nonrefs;
typedef struct _jc_java_awt_Container__24GfxVisitor$object	_jc_java_awt_Container__24GfxVisitor$object;

typedef const struct _jc_java_awt_Container__24GfxVisitor$vmethods	_jc_java_awt_Container__24GfxVisitor$vmethods;
typedef const struct _jc_java_awt_Container__24GfxVisitor$vtable	_jc_java_awt_Container__24GfxVisitor$vtable;
typedef const struct _jc_java_awt_Container__24GfxVisitor$vtype	_jc_java_awt_Container__24GfxVisitor$vtype;

// Constructors
extern void _jc_java_awt_Container__24GfxVisitor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_Container__24GfxVisitor$object *);

// Virtual methods
extern void _jc_java_awt_Container__24GfxVisitor$method$visit$0c80e38e76a498e6(_jc_env *, struct _jc_java_awt_Container__24GfxVisitor$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Container__24GfxVisitor$method_info$visit$0c80e38e76a498e6;

// Virtual methods structure
struct _jc_java_awt_Container__24GfxVisitor$vmethods {
	void	(*visit$0c80e38e76a498e6)(_jc_env *, struct _jc_java_awt_Container__24GfxVisitor$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *);
};

// Vtable
struct _jc_java_awt_Container__24GfxVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Container__24GfxVisitor$vmethods	java_awt_Container__24GfxVisitor;
};

// Vtype
struct _jc_java_awt_Container__24GfxVisitor$vtype {
	_jc_type			type;
	_jc_java_awt_Container__24GfxVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Container__24GfxVisitor$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_Container__24GfxVisitor$refs {
    _jc_java_awt_Container__24GfxVisitor$sub_refs	java_awt_Container__24GfxVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Container__24GfxVisitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Container__24GfxVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Container__24GfxVisitor$sub_nonrefs	java_awt_Container__24GfxVisitor;
};

// Object instance structure
struct _jc_java_awt_Container__24GfxVisitor$object {
	_jc_java_awt_Container__24GfxVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Container__24GfxVisitor$vtype	*vtype;
	_jc_java_awt_Container__24GfxVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Container__24GfxVisitor$vtype _jc_java_awt_Container__24GfxVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Container__24GfxVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Container__24GfxVisitor$class_object;

#endif	/* _JC_java_awt_Container__24GfxVisitor_H_ */

==> jc-1.4.6.tar.gz: java/awt/Container__24GfxVisitor.h <==
// abstract class java.awt.Container$GfxVisitor

// class file dependencies
// @dep_class a0c7f2977640055f java_awt_Container__24GfxVisitor
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Container__24GfxVisitor_H_
#define _JC_java_awt_Container__24GfxVisitor_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Container__24GfxVisitor$sub_refs	_jc_java_awt_Container__24GfxVisitor$sub_refs;
typedef struct _jc_java_awt_Container__24GfxVisitor$sub_nonrefs	_jc_java_awt_Container__24GfxVisitor$sub_nonrefs;
typedef struct _jc_java_awt_Container__24GfxVisitor$refs	_jc_java_awt_Container__24GfxVisitor$refs;
typedef struct _jc_java_awt_Container__24GfxVisitor$nonrefs	_jc_java_awt_Container__24GfxVisitor$nonrefs;
typedef struct _jc_java_awt_Container__24GfxVisitor$object	_jc_java_awt_Container__24GfxVisitor$object;

typedef const struct _jc_java_awt_Container__24GfxVisitor$vmethods	_jc_java_awt_Container__24GfxVisitor$vmethods;
typedef const struct _jc_java_awt_Container__24GfxVisitor$vtable	_jc_java_awt_Container__24GfxVisitor$vtable;
typedef const struct _jc_java_awt_Container__24GfxVisitor$vtype	_jc_java_awt_Container__24GfxVisitor$vtype;

// Constructors
extern void _jc_java_awt_Container__24GfxVisitor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_Container__24GfxVisitor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_Container__24GfxVisitor$method$visit$0c80e38e76a498e6(_jc_env *, struct _jc_java_awt_Container__24GfxVisitor$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Container__24GfxVisitor$method_info$visit$0c80e38e76a498e6;

// Virtual methods structure
struct _jc_java_awt_Container__24GfxVisitor$vmethods {
	void	(*visit$0c80e38e76a498e6)(_jc_env *, struct _jc_java_awt_Container__24GfxVisitor$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Container__24GfxVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Container__24GfxVisitor$vmethods	java_awt_Container__24GfxVisitor;
};

// Vtype
struct _jc_java_awt_Container__24GfxVisitor$vtype {
	_jc_type			type;
	_jc_java_awt_Container__24GfxVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Container__24GfxVisitor$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_Container__24GfxVisitor$refs {
    _jc_java_awt_Container__24GfxVisitor$sub_refs	java_awt_Container__24GfxVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Container__24GfxVisitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Container__24GfxVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Container__24GfxVisitor$sub_nonrefs	java_awt_Container__24GfxVisitor;
};

// Object instance structure
struct _jc_java_awt_Container__24GfxVisitor$object {
	_jc_java_awt_Container__24GfxVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Container__24GfxVisitor$vtype	*vtype;
	_jc_java_awt_Container__24GfxVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Container__24GfxVisitor$vtype _jc_java_awt_Container__24GfxVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Container__24GfxVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Container__24GfxVisitor$class_object;

#endif	/* _JC_java_awt_Container__24GfxVisitor_H_ */
